pub trait ConfigPlugin:
Send
+ Sync
+ 'static {
// Required methods
fn name(&self) -> String;
fn gen_config(&self) -> Result<HashMap<String, String>, String>;
// Provided methods
fn gen_pack(&self, name: &str, _value: &str) -> Result<String, String> { ... }
fn shutdown(&self) { ... }
}Expand description
Trait for implementing configuration plugins in osquery-rust.
Configuration plugins provide osquery with its configuration data, which can come from various sources like files, HTTP endpoints, or other custom sources.
Required Methods
Provided Methods
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".